@@ -5,7 +5,8 @@
 
     WSGI app server for livereload.
 
-    :copyright: (c) 2013 by Hsiaoming Yang
+    :copyright: (c) 2013 - 2015 by Hsiaoming Yang
+    :license: BSD, see LICENSE for more details.
 """
 
 import os
@@ -130,7 +131,7 @@ class LiveScriptContainer(WSGIContainer):
 
         if status_code != 304:
             if "content-type" not in header_set:
-                headers.append(("Content-Type", "text/html; charset=UTF-8"))
+                headers.append(("Content-Type", "application/octet-stream; charset=UTF-8"))
             if "content-length" not in header_set:
                 headers.append(("Content-Length", str(len(body))))
 
@@ -142,7 +143,7 @@ class LiveScriptContainer(WSGIContainer):
         )
         header_obj = httputil.HTTPHeaders()
         for key, value in headers:
-            if key == 'Content-Length':
+            if key.lower() == 'content-length':
                 value = str(len(body))
             header_obj.add(key, value)
         request.connection.write_headers(start_line, header_obj, chunk=body)
@@ -173,7 +174,7 @@ class Server(object):
             watcher = watcher_cls()
         self.watcher = watcher
 
-    def watch(self, filepath, func=None, delay=None):
+    def watch(self, filepath, func=None, delay=None, ignore=None):
         """Add the given filepath for watcher list.
 
         Once you have intialized a server, watch file changes before
@@ -193,14 +194,17 @@ class Server(object):
         :param delay: Delay sending the reload message. Use 'forever' to
                       not send it. This is useful to compile sass files to
                       css, but reload on changed css files then only.
+        :param ignore: A function return True to ignore a certain pattern of
+                       filepath.
         """
         if isinstance(func, string_types):
             func = shell(func)
 
-        self.watcher.watch(filepath, func, delay)
+        self.watcher.watch(filepath, func, delay, ignore=ignore)
 
-    def application(self, port, host, liveport=None, debug=None):
+    def application(self, port, host, liveport=None, debug=None, live_css=True):
         LiveReloadHandler.watcher = self.watcher
+        LiveReloadHandler.live_css = live_css
         if liveport is None:
             liveport = port
         if debug is None and self.app:
@@ -212,9 +216,16 @@ class Server(object):
             (r'/livereload.js', LiveReloadJSHandler)
         ]
 
+        # The livereload.js snippet.
+        # Uses JavaScript to dynamically inject the client's hostname.
+        # This allows for serving on 0.0.0.0.
         live_script = escape.utf8((
-            '<script src="http://{host}:{port}/livereload.js"></script>'
-        ).format(host=host, port=liveport))
+            '<script type="text/javascript">'
+            'document.write("<script src=''http://"'
+            ' + window.location.hostname + ":{port}/livereload.js''>'
+            ' </"+"script>");'
+            '</script>'
+        ).format(port=liveport))
 
         web_handlers = self.get_web_handlers(live_script)
 
@@ -251,7 +262,7 @@ class Server(object):
         ]
 
     def serve(self, port=5500, liveport=None, host=None, root=None, debug=None,
-              open_url=False, restart_delay=2, open_url_delay=None):
+              open_url=False, restart_delay=2, open_url_delay=None, live_css=True):
         """Start serve the server with the given port.
 
         :param port: serve on this port, default is 5500
@@ -262,6 +273,7 @@ class Server(object):
                       via Tornado (and causes polling). Defaults to True when
                       ``self.app`` is set, otherwise False.
         :param open_url_delay: open webbrowser after the delay seconds
+        :param live_css: whether to use live css or force reload on css. Defaults to True
         """
         host = host or '127.0.0.1'
         if root is not None:
@@ -270,7 +282,7 @@ class Server(object):
         self._setup_logging()
         logger.info('Serving on http://%s:%s' % (host, port))
 
-        self.application(port, host, liveport=liveport, debug=debug)
+        self.application(port, host, liveport=liveport, debug=debug, live_css=live_css)
 
         # Async open web browser after 5 sec timeout
         if open_url or open_url_delay:
