@@ -6,6 +6,7 @@
     A file watch management for LiveReload Server.
 
     :copyright: (c) 2013 - 2015 by Hsiaoming Yang
+    :license: BSD, see LICENSE for more details.
 """
 
 import os
@@ -71,7 +72,7 @@ class Watcher(object):
                 func = item['func']
                 func and func()
                 delay = item['delay']
-                if delay and isinstance(delay, int):
+                if delay and isinstance(delay, float):
                     delays.add(delay)
 
         if delays:
@@ -165,6 +166,6 @@ class INotifyWatcher(Watcher):
 
 
 def get_watcher_class():
-    if pyinotify is None:
+    if pyinotify is None or not hasattr(pyinotify, 'TornadoAsyncNotifier'):
         return Watcher
     return INotifyWatcher
